@@ -2,6 +2,7 @@
 # Licensed under the Apache License, Version 2.0 - see LICENSE file.
 import numpy as np
 
+from inferlo import GenericGraphModel, DiscreteDomain
 from inferlo.base import DiscreteFactor
 from inferlo.pairwise import PairWiseFiniteModel
 from inferlo.base.inference_result import InferenceResult
@@ -118,3 +119,21 @@ def test_encode_state():
 
     model = PairWiseFiniteModel(5, 10)
     assert model.encode_state([5, 4, 3, 2, 1]) == 12345
+
+
+def test_from_model():
+    model1 = GenericGraphModel(3)
+    model1[0].domain = DiscreteDomain.binary()
+    model1[2].domain = DiscreteDomain([0, 10])
+    model1[1].domain = DiscreteDomain.range(3)
+    x0, x1, x2 = model1.get_symbolic_variables()
+    model1.add_factor(np.exp(x0 + x1))
+    model1.add_factor(np.exp(x1 + x2))
+    model2 = PairWiseFiniteModel.from_model(model1)
+
+    assert np.allclose(model2.field, np.zeros((3, 3)))
+    assert model2.edges == [(0, 1), (1, 2)]
+    assert np.allclose(model2.get_all_interactions(), np.array([
+        [[0, 1, 2], [1, 2, 3], [-np.inf, -np.inf, -np.inf]],
+        [[0, 10, -np.inf], [1, 11, -np.inf], [2, 12, -np.inf]]
+    ]))
